
# Slot: decreases molecular modification of


holds between two molecular entities where the action or effect of one leads to decreased molecular modification(s) of the other (e.g. via post-translational modifications of proteins such as the addition of phosphoryl group, or via redox reaction that adds or subtracts electrons)

URI: [biolink:decreases_molecular_modification_of](https://w3id.org/biolink/vocab/decreases_molecular_modification_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects molecular modification of](affects_molecular_modification_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:decreases_molecular_modification_of |
| **Narrow Mappings:** | | CTD:decreases_acetylation |
|  | | CTD:decreases_acylation |
|  | | CTD:decreases_alkylation |
|  | | CTD:decreases_amination |
|  | | CTD:decreases_carbamoylation |
|  | | CTD:decreases_ethylation |
|  | | CTD:decreases_glutathionylation |
|  | | CTD:decreases_glycation |
|  | | CTD:decreases_glycosylation |
|  | | CTD:decreases_glucuronidation |
|  | | CTD:decreases_N-linked_glycosylation |
|  | | CTD:decreases_O-linked_glycosylation |
|  | | CTD:decreases_hydroxylation |
|  | | CTD:decreases_lipidation |
|  | | CTD:decreases_farnesylation |
|  | | CTD:decreases_geranoylation |
|  | | CTD:decreases_myristoylation |
|  | | CTD:decreases_palmitoylation |
|  | | CTD:decreases_prenylation |
|  | | CTD:decreases_methylation |
|  | | CTD:decreases_nitrosation |
|  | | CTD:decreases_nucleotidylation |
|  | | CTD:decreases_phosphorylation |
|  | | CTD:decreases_ribosylation |
|  | | CTD:decreases_ADP-ribosylation |
|  | | CTD:decreases_sulfation |
|  | | CTD:decreases_sumoylation |
|  | | CTD:decreases_ubiquitination |
|  | | CTD:decreases_oxidation |
|  | | CTD:decreases_reduction |
|  | | CTD:decreases_carboxylation |
|  | | GAMMA:deoxidizer |

